@@ -5,6 +5,6 @@ from models.user import User
 
 if __name__ == '__main__':
 
-    Database().connect(**db)
+    Database.connect(**db)
 
     User.truncate()
